# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from alphaxiv_cat import AlphaxivCat, AsyncAlphaxivCat
from alphaxiv_cat.types.retool import (
    V1GetTotalUserCountResponse,
    V1GetCumulativeUsersResponse,
    V1GetTotalPaperCountResponse,
    V1GetDailyNewAccountsResponse,
    V1GetTotalCommentCountResponse,
    V1GetDailyConversationsResponse,
    V1GetWeeklyPrivateNotesResponse,
    V1GetWeeklyPublicCommentsResponse,
    V1GetDailyUserChatMessagesResponse,
    V1GetTotalPrivateNotesCountResponse,
    V1GetWeeklyMessageCountsByUserResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestV1:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_get_cumulative_users(self, client: AlphaxivCat) -> None:
        v1 = client.retool.v1.get_cumulative_users()
        assert_matches_type(V1GetCumulativeUsersResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_get_cumulative_users(self, client: AlphaxivCat) -> None:
        response = client.retool.v1.with_raw_response.get_cumulative_users()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1GetCumulativeUsersResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_get_cumulative_users(self, client: AlphaxivCat) -> None:
        with client.retool.v1.with_streaming_response.get_cumulative_users() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1GetCumulativeUsersResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_get_daily_conversations(self, client: AlphaxivCat) -> None:
        v1 = client.retool.v1.get_daily_conversations()
        assert_matches_type(V1GetDailyConversationsResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_get_daily_conversations(self, client: AlphaxivCat) -> None:
        response = client.retool.v1.with_raw_response.get_daily_conversations()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1GetDailyConversationsResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_get_daily_conversations(self, client: AlphaxivCat) -> None:
        with client.retool.v1.with_streaming_response.get_daily_conversations() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1GetDailyConversationsResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_get_daily_new_accounts(self, client: AlphaxivCat) -> None:
        v1 = client.retool.v1.get_daily_new_accounts()
        assert_matches_type(V1GetDailyNewAccountsResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_get_daily_new_accounts(self, client: AlphaxivCat) -> None:
        response = client.retool.v1.with_raw_response.get_daily_new_accounts()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1GetDailyNewAccountsResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_get_daily_new_accounts(self, client: AlphaxivCat) -> None:
        with client.retool.v1.with_streaming_response.get_daily_new_accounts() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1GetDailyNewAccountsResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_get_daily_user_chat_messages(self, client: AlphaxivCat) -> None:
        v1 = client.retool.v1.get_daily_user_chat_messages()
        assert_matches_type(V1GetDailyUserChatMessagesResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_get_daily_user_chat_messages(self, client: AlphaxivCat) -> None:
        response = client.retool.v1.with_raw_response.get_daily_user_chat_messages()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1GetDailyUserChatMessagesResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_get_daily_user_chat_messages(self, client: AlphaxivCat) -> None:
        with client.retool.v1.with_streaming_response.get_daily_user_chat_messages() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1GetDailyUserChatMessagesResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_get_total_comment_count(self, client: AlphaxivCat) -> None:
        v1 = client.retool.v1.get_total_comment_count()
        assert_matches_type(V1GetTotalCommentCountResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_get_total_comment_count(self, client: AlphaxivCat) -> None:
        response = client.retool.v1.with_raw_response.get_total_comment_count()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1GetTotalCommentCountResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_get_total_comment_count(self, client: AlphaxivCat) -> None:
        with client.retool.v1.with_streaming_response.get_total_comment_count() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1GetTotalCommentCountResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_get_total_paper_count(self, client: AlphaxivCat) -> None:
        v1 = client.retool.v1.get_total_paper_count()
        assert_matches_type(V1GetTotalPaperCountResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_get_total_paper_count(self, client: AlphaxivCat) -> None:
        response = client.retool.v1.with_raw_response.get_total_paper_count()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1GetTotalPaperCountResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_get_total_paper_count(self, client: AlphaxivCat) -> None:
        with client.retool.v1.with_streaming_response.get_total_paper_count() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1GetTotalPaperCountResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_get_total_private_notes_count(self, client: AlphaxivCat) -> None:
        v1 = client.retool.v1.get_total_private_notes_count()
        assert_matches_type(V1GetTotalPrivateNotesCountResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_get_total_private_notes_count(self, client: AlphaxivCat) -> None:
        response = client.retool.v1.with_raw_response.get_total_private_notes_count()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1GetTotalPrivateNotesCountResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_get_total_private_notes_count(self, client: AlphaxivCat) -> None:
        with client.retool.v1.with_streaming_response.get_total_private_notes_count() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1GetTotalPrivateNotesCountResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_get_total_user_count(self, client: AlphaxivCat) -> None:
        v1 = client.retool.v1.get_total_user_count()
        assert_matches_type(V1GetTotalUserCountResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_get_total_user_count(self, client: AlphaxivCat) -> None:
        response = client.retool.v1.with_raw_response.get_total_user_count()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1GetTotalUserCountResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_get_total_user_count(self, client: AlphaxivCat) -> None:
        with client.retool.v1.with_streaming_response.get_total_user_count() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1GetTotalUserCountResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_get_weekly_message_counts_by_user(self, client: AlphaxivCat) -> None:
        v1 = client.retool.v1.get_weekly_message_counts_by_user()
        assert_matches_type(V1GetWeeklyMessageCountsByUserResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_get_weekly_message_counts_by_user(self, client: AlphaxivCat) -> None:
        response = client.retool.v1.with_raw_response.get_weekly_message_counts_by_user()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1GetWeeklyMessageCountsByUserResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_get_weekly_message_counts_by_user(self, client: AlphaxivCat) -> None:
        with client.retool.v1.with_streaming_response.get_weekly_message_counts_by_user() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1GetWeeklyMessageCountsByUserResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_get_weekly_private_notes(self, client: AlphaxivCat) -> None:
        v1 = client.retool.v1.get_weekly_private_notes()
        assert_matches_type(V1GetWeeklyPrivateNotesResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_get_weekly_private_notes(self, client: AlphaxivCat) -> None:
        response = client.retool.v1.with_raw_response.get_weekly_private_notes()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1GetWeeklyPrivateNotesResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_get_weekly_private_notes(self, client: AlphaxivCat) -> None:
        with client.retool.v1.with_streaming_response.get_weekly_private_notes() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1GetWeeklyPrivateNotesResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_get_weekly_public_comments(self, client: AlphaxivCat) -> None:
        v1 = client.retool.v1.get_weekly_public_comments()
        assert_matches_type(V1GetWeeklyPublicCommentsResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_get_weekly_public_comments(self, client: AlphaxivCat) -> None:
        response = client.retool.v1.with_raw_response.get_weekly_public_comments()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1GetWeeklyPublicCommentsResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_get_weekly_public_comments(self, client: AlphaxivCat) -> None:
        with client.retool.v1.with_streaming_response.get_weekly_public_comments() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1GetWeeklyPublicCommentsResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncV1:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_get_cumulative_users(self, async_client: AsyncAlphaxivCat) -> None:
        v1 = await async_client.retool.v1.get_cumulative_users()
        assert_matches_type(V1GetCumulativeUsersResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_get_cumulative_users(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.retool.v1.with_raw_response.get_cumulative_users()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1GetCumulativeUsersResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_get_cumulative_users(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.retool.v1.with_streaming_response.get_cumulative_users() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1GetCumulativeUsersResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_get_daily_conversations(self, async_client: AsyncAlphaxivCat) -> None:
        v1 = await async_client.retool.v1.get_daily_conversations()
        assert_matches_type(V1GetDailyConversationsResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_get_daily_conversations(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.retool.v1.with_raw_response.get_daily_conversations()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1GetDailyConversationsResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_get_daily_conversations(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.retool.v1.with_streaming_response.get_daily_conversations() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1GetDailyConversationsResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_get_daily_new_accounts(self, async_client: AsyncAlphaxivCat) -> None:
        v1 = await async_client.retool.v1.get_daily_new_accounts()
        assert_matches_type(V1GetDailyNewAccountsResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_get_daily_new_accounts(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.retool.v1.with_raw_response.get_daily_new_accounts()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1GetDailyNewAccountsResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_get_daily_new_accounts(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.retool.v1.with_streaming_response.get_daily_new_accounts() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1GetDailyNewAccountsResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_get_daily_user_chat_messages(self, async_client: AsyncAlphaxivCat) -> None:
        v1 = await async_client.retool.v1.get_daily_user_chat_messages()
        assert_matches_type(V1GetDailyUserChatMessagesResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_get_daily_user_chat_messages(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.retool.v1.with_raw_response.get_daily_user_chat_messages()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1GetDailyUserChatMessagesResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_get_daily_user_chat_messages(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.retool.v1.with_streaming_response.get_daily_user_chat_messages() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1GetDailyUserChatMessagesResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_get_total_comment_count(self, async_client: AsyncAlphaxivCat) -> None:
        v1 = await async_client.retool.v1.get_total_comment_count()
        assert_matches_type(V1GetTotalCommentCountResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_get_total_comment_count(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.retool.v1.with_raw_response.get_total_comment_count()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1GetTotalCommentCountResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_get_total_comment_count(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.retool.v1.with_streaming_response.get_total_comment_count() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1GetTotalCommentCountResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_get_total_paper_count(self, async_client: AsyncAlphaxivCat) -> None:
        v1 = await async_client.retool.v1.get_total_paper_count()
        assert_matches_type(V1GetTotalPaperCountResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_get_total_paper_count(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.retool.v1.with_raw_response.get_total_paper_count()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1GetTotalPaperCountResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_get_total_paper_count(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.retool.v1.with_streaming_response.get_total_paper_count() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1GetTotalPaperCountResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_get_total_private_notes_count(self, async_client: AsyncAlphaxivCat) -> None:
        v1 = await async_client.retool.v1.get_total_private_notes_count()
        assert_matches_type(V1GetTotalPrivateNotesCountResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_get_total_private_notes_count(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.retool.v1.with_raw_response.get_total_private_notes_count()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1GetTotalPrivateNotesCountResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_get_total_private_notes_count(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.retool.v1.with_streaming_response.get_total_private_notes_count() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1GetTotalPrivateNotesCountResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_get_total_user_count(self, async_client: AsyncAlphaxivCat) -> None:
        v1 = await async_client.retool.v1.get_total_user_count()
        assert_matches_type(V1GetTotalUserCountResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_get_total_user_count(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.retool.v1.with_raw_response.get_total_user_count()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1GetTotalUserCountResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_get_total_user_count(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.retool.v1.with_streaming_response.get_total_user_count() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1GetTotalUserCountResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_get_weekly_message_counts_by_user(self, async_client: AsyncAlphaxivCat) -> None:
        v1 = await async_client.retool.v1.get_weekly_message_counts_by_user()
        assert_matches_type(V1GetWeeklyMessageCountsByUserResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_get_weekly_message_counts_by_user(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.retool.v1.with_raw_response.get_weekly_message_counts_by_user()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1GetWeeklyMessageCountsByUserResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_get_weekly_message_counts_by_user(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.retool.v1.with_streaming_response.get_weekly_message_counts_by_user() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1GetWeeklyMessageCountsByUserResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_get_weekly_private_notes(self, async_client: AsyncAlphaxivCat) -> None:
        v1 = await async_client.retool.v1.get_weekly_private_notes()
        assert_matches_type(V1GetWeeklyPrivateNotesResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_get_weekly_private_notes(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.retool.v1.with_raw_response.get_weekly_private_notes()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1GetWeeklyPrivateNotesResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_get_weekly_private_notes(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.retool.v1.with_streaming_response.get_weekly_private_notes() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1GetWeeklyPrivateNotesResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_get_weekly_public_comments(self, async_client: AsyncAlphaxivCat) -> None:
        v1 = await async_client.retool.v1.get_weekly_public_comments()
        assert_matches_type(V1GetWeeklyPublicCommentsResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_get_weekly_public_comments(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.retool.v1.with_raw_response.get_weekly_public_comments()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1GetWeeklyPublicCommentsResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_get_weekly_public_comments(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.retool.v1.with_streaming_response.get_weekly_public_comments() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1GetWeeklyPublicCommentsResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["V3UpdateParentParams"]


class V3UpdateParentParams(TypedDict, total=False):
    parent_id: Required[Annotated[Optional[str], PropertyInfo(alias="parentId")]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import typing_extensions

import httpx

from ...._types import Body, Omit, Query, Headers, NoneType, NotGiven, omit, not_given
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.papers.v3 import x_mention_update_params
from ....types.papers.v3.x_mention_update_response import XMentionUpdateResponse

__all__ = ["XMentionsResource", "AsyncXMentionsResource"]


class XMentionsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> XMentionsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return XMentionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> XMentionsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return XMentionsResourceWithStreamingResponse(self)

    @typing_extensions.deprecated("deprecated")
    def update(
        self,
        paper_group_id: str,
        *,
        dry_run: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> XMentionUpdateResponse:
        """
        Search for X (Twitter) mentions of a paper, filter for quality, and save to
        database

        Source file:
        `api-server/src/controllers/papers/v3/get-paper-x-mentions.controller.ts`

        Args:
          paper_group_id: Paper group ID (UUID)

          dry_run: If true, only logs results without saving to database

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not paper_group_id:
            raise ValueError(f"Expected a non-empty value for `paper_group_id` but received {paper_group_id!r}")
        return self._post(
            f"/papers/v3/x-mentions/{paper_group_id}",
            body=maybe_transform({"dry_run": dry_run}, x_mention_update_params.XMentionUpdateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=XMentionUpdateResponse,
        )

    def delete(
        self,
        paper_group_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Delete all X (Twitter) mentions for a paper

        Source file:
        `api-server/src/controllers/papers/v3/delete-paper-x-mentions.controller.ts`

        Args:
          paper_group_id: Paper group ID (UUID)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not paper_group_id:
            raise ValueError(f"Expected a non-empty value for `paper_group_id` but received {paper_group_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/papers/v3/x-mentions/{paper_group_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncXMentionsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncXMentionsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncXMentionsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncXMentionsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncXMentionsResourceWithStreamingResponse(self)

    @typing_extensions.deprecated("deprecated")
    async def update(
        self,
        paper_group_id: str,
        *,
        dry_run: bool | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> XMentionUpdateResponse:
        """
        Search for X (Twitter) mentions of a paper, filter for quality, and save to
        database

        Source file:
        `api-server/src/controllers/papers/v3/get-paper-x-mentions.controller.ts`

        Args:
          paper_group_id: Paper group ID (UUID)

          dry_run: If true, only logs results without saving to database

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not paper_group_id:
            raise ValueError(f"Expected a non-empty value for `paper_group_id` but received {paper_group_id!r}")
        return await self._post(
            f"/papers/v3/x-mentions/{paper_group_id}",
            body=await async_maybe_transform({"dry_run": dry_run}, x_mention_update_params.XMentionUpdateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=XMentionUpdateResponse,
        )

    async def delete(
        self,
        paper_group_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Delete all X (Twitter) mentions for a paper

        Source file:
        `api-server/src/controllers/papers/v3/delete-paper-x-mentions.controller.ts`

        Args:
          paper_group_id: Paper group ID (UUID)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not paper_group_id:
            raise ValueError(f"Expected a non-empty value for `paper_group_id` but received {paper_group_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/papers/v3/x-mentions/{paper_group_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class XMentionsResourceWithRawResponse:
    def __init__(self, x_mentions: XMentionsResource) -> None:
        self._x_mentions = x_mentions

        self.update = (  # pyright: ignore[reportDeprecated]
            to_raw_response_wrapper(
                x_mentions.update,  # pyright: ignore[reportDeprecated],
            )
        )
        self.delete = to_raw_response_wrapper(
            x_mentions.delete,
        )


class AsyncXMentionsResourceWithRawResponse:
    def __init__(self, x_mentions: AsyncXMentionsResource) -> None:
        self._x_mentions = x_mentions

        self.update = (  # pyright: ignore[reportDeprecated]
            async_to_raw_response_wrapper(
                x_mentions.update,  # pyright: ignore[reportDeprecated],
            )
        )
        self.delete = async_to_raw_response_wrapper(
            x_mentions.delete,
        )


class XMentionsResourceWithStreamingResponse:
    def __init__(self, x_mentions: XMentionsResource) -> None:
        self._x_mentions = x_mentions

        self.update = (  # pyright: ignore[reportDeprecated]
            to_streamed_response_wrapper(
                x_mentions.update,  # pyright: ignore[reportDeprecated],
            )
        )
        self.delete = to_streamed_response_wrapper(
            x_mentions.delete,
        )


class AsyncXMentionsResourceWithStreamingResponse:
    def __init__(self, x_mentions: AsyncXMentionsResource) -> None:
        self._x_mentions = x_mentions

        self.update = (  # pyright: ignore[reportDeprecated]
            async_to_streamed_response_wrapper(
                x_mentions.update,  # pyright: ignore[reportDeprecated],
            )
        )
        self.delete = async_to_streamed_response_wrapper(
            x_mentions.delete,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v1 import (
    V1Resource,
    AsyncV1Resource,
    V1ResourceWithRawResponse,
    AsyncV1ResourceWithRawResponse,
    V1ResourceWithStreamingResponse,
    AsyncV1ResourceWithStreamingResponse,
)
from .labs import (
    LabsResource,
    AsyncLabsResource,
    LabsResourceWithRawResponse,
    AsyncLabsResourceWithRawResponse,
    LabsResourceWithStreamingResponse,
    AsyncLabsResourceWithStreamingResponse,
)

__all__ = [
    "LabsResource",
    "AsyncLabsResource",
    "LabsResourceWithRawResponse",
    "AsyncLabsResourceWithRawResponse",
    "LabsResourceWithStreamingResponse",
    "AsyncLabsResourceWithStreamingResponse",
    "V1Resource",
    "AsyncV1Resource",
    "V1ResourceWithRawResponse",
    "AsyncV1ResourceWithRawResponse",
    "V1ResourceWithStreamingResponse",
    "AsyncV1ResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = [
    "LegacyRetrieveResponse",
    "Comment",
    "CommentAnnotation",
    "CommentAnnotationAnchorPosition",
    "CommentAnnotationFocusPosition",
    "CommentAnnotationHighlightRect",
    "CommentAnnotationHighlightRectRect",
    "CommentAuthor",
    "CommentAuthorAvatar",
    "CommentEndorsement",
    "CommentResponse",
    "CommentResponseAnnotation",
    "CommentResponseAnnotationAnchorPosition",
    "CommentResponseAnnotationFocusPosition",
    "CommentResponseAnnotationHighlightRect",
    "CommentResponseAnnotationHighlightRectRect",
    "CommentResponseAuthor",
    "CommentResponseAuthorAvatar",
    "CommentResponseEndorsement",
]


class CommentAnnotationAnchorPosition(BaseModel):
    offset: float

    page_index: float = FieldInfo(alias="pageIndex")

    span_index: float = FieldInfo(alias="spanIndex")


class CommentAnnotationFocusPosition(BaseModel):
    offset: float

    page_index: float = FieldInfo(alias="pageIndex")

    span_index: float = FieldInfo(alias="spanIndex")


class CommentAnnotationHighlightRectRect(BaseModel):
    x1: float

    x2: float

    y1: float

    y2: float


class CommentAnnotationHighlightRect(BaseModel):
    page_index: float = FieldInfo(alias="pageIndex")

    rects: List[CommentAnnotationHighlightRectRect]


class CommentAnnotation(BaseModel):
    anchor_position: CommentAnnotationAnchorPosition = FieldInfo(alias="anchorPosition")

    focus_position: CommentAnnotationFocusPosition = FieldInfo(alias="focusPosition")

    highlight_rects: List[CommentAnnotationHighlightRect] = FieldInfo(alias="highlightRects")

    selected_text: str = FieldInfo(alias="selectedText")

    type: Literal["highlight"]

    color: Optional[str] = None


class CommentAuthorAvatar(BaseModel):
    type: Literal["full_size", "thumbnail"]

    url: str


class CommentAuthor(BaseModel):
    id: str

    avatar: Optional[List[CommentAuthorAvatar]] = None

    bluesky_username: Optional[str] = FieldInfo(alias="blueskyUsername", default=None)

    github_username: Optional[str] = FieldInfo(alias="githubUsername", default=None)

    google_scholar_id: Optional[str] = FieldInfo(alias="googleScholarId", default=None)

    institution: Optional[str] = None

    linkedin_username: Optional[str] = FieldInfo(alias="linkedinUsername", default=None)

    orcid_id: Optional[str] = FieldInfo(alias="orcidId", default=None)

    public_email: Optional[str] = FieldInfo(alias="publicEmail", default=None)

    real_name: str = FieldInfo(alias="realName")

    reputation: float

    role: Literal["user", "reviewer", "admin", "bot"]

    username: str

    verified: bool

    weekly_reputation: float = FieldInfo(alias="weeklyReputation")

    x_username: Optional[str] = FieldInfo(alias="xUsername", default=None)


class CommentEndorsement(BaseModel):
    id: str

    name: str


class CommentResponseAnnotationAnchorPosition(BaseModel):
    offset: float

    page_index: float = FieldInfo(alias="pageIndex")

    span_index: float = FieldInfo(alias="spanIndex")


class CommentResponseAnnotationFocusPosition(BaseModel):
    offset: float

    page_index: float = FieldInfo(alias="pageIndex")

    span_index: float = FieldInfo(alias="spanIndex")


class CommentResponseAnnotationHighlightRectRect(BaseModel):
    x1: float

    x2: float

    y1: float

    y2: float


class CommentResponseAnnotationHighlightRect(BaseModel):
    page_index: float = FieldInfo(alias="pageIndex")

    rects: List[CommentResponseAnnotationHighlightRectRect]


class CommentResponseAnnotation(BaseModel):
    anchor_position: CommentResponseAnnotationAnchorPosition = FieldInfo(alias="anchorPosition")

    focus_position: CommentResponseAnnotationFocusPosition = FieldInfo(alias="focusPosition")

    highlight_rects: List[CommentResponseAnnotationHighlightRect] = FieldInfo(alias="highlightRects")

    selected_text: str = FieldInfo(alias="selectedText")

    type: Literal["highlight"]

    color: Optional[str] = None


class CommentResponseAuthorAvatar(BaseModel):
    type: Literal["full_size", "thumbnail"]

    url: str


class CommentResponseAuthor(BaseModel):
    id: str

    avatar: Optional[List[CommentResponseAuthorAvatar]] = None

    bluesky_username: Optional[str] = FieldInfo(alias="blueskyUsername", default=None)

    github_username: Optional[str] = FieldInfo(alias="githubUsername", default=None)

    google_scholar_id: Optional[str] = FieldInfo(alias="googleScholarId", default=None)

    institution: Optional[str] = None

    linkedin_username: Optional[str] = FieldInfo(alias="linkedinUsername", default=None)

    orcid_id: Optional[str] = FieldInfo(alias="orcidId", default=None)

    public_email: Optional[str] = FieldInfo(alias="publicEmail", default=None)

    real_name: str = FieldInfo(alias="realName")

    reputation: float

    role: Literal["user", "reviewer", "admin", "bot"]

    username: str

    verified: bool

    weekly_reputation: float = FieldInfo(alias="weeklyReputation")

    x_username: Optional[str] = FieldInfo(alias="xUsername", default=None)


class CommentResponseEndorsement(BaseModel):
    id: str

    name: str


class CommentResponse(BaseModel):
    id: str

    annotation: Optional[CommentResponseAnnotation] = None

    author: CommentResponseAuthor

    author_responded: bool = FieldInfo(alias="authorResponded")

    body: Optional[str] = None

    date: str

    endorsements: List[CommentResponseEndorsement]

    has_downvoted: bool = FieldInfo(alias="hasDownvoted")

    has_flagged: bool = FieldInfo(alias="hasFlagged")

    has_upvoted: bool = FieldInfo(alias="hasUpvoted")

    is_author: bool = FieldInfo(alias="isAuthor")

    paper_group_id: str = FieldInfo(alias="paperGroupId")

    paper_title: str = FieldInfo(alias="paperTitle")

    paper_version_id: str = FieldInfo(alias="paperVersionId")

    tag: str

    title: Optional[str] = None

    universal_id: str = FieldInfo(alias="universalId")

    upvotes: float

    was_edited: bool = FieldInfo(alias="wasEdited")


class Comment(BaseModel):
    id: str

    annotation: Optional[CommentAnnotation] = None

    author: CommentAuthor

    author_responded: bool = FieldInfo(alias="authorResponded")

    body: Optional[str] = None

    date: str

    endorsements: List[CommentEndorsement]

    has_downvoted: bool = FieldInfo(alias="hasDownvoted")

    has_flagged: bool = FieldInfo(alias="hasFlagged")

    has_upvoted: bool = FieldInfo(alias="hasUpvoted")

    is_author: bool = FieldInfo(alias="isAuthor")

    paper_group_id: str = FieldInfo(alias="paperGroupId")

    paper_title: str = FieldInfo(alias="paperTitle")

    paper_version_id: str = FieldInfo(alias="paperVersionId")

    responses: List[CommentResponse]

    tag: str

    title: Optional[str] = None

    universal_id: str = FieldInfo(alias="universalId")

    upvotes: float

    was_edited: bool = FieldInfo(alias="wasEdited")


class LegacyRetrieveResponse(BaseModel):
    comments: List[Comment]

    paper: Optional[object] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from alphaxiv_cat import AlphaxivCat, AsyncAlphaxivCat
from alphaxiv_cat.types import (
    PaperVoteResponse,
    PaperUnclaimResponse,
    PaperAddAuthorResponse,
    PaperAdminVoteResponse,
    PaperCrxPdfHitResponse,
    PaperKickoffAIResponse,
    PaperCrxPdfClickResponse,
    PaperEmailAuthorResponse,
    PaperGetPaperInfoResponse,
    PaperToggleFollowResponse,
    PaperKickoffBibtexResponse,
    PaperKickoffGitHubResponse,
    PaperCrxAbstractHitResponse,
    PaperGetCrxPaperInfoResponse,
    PaperProcessMetadataResponse,
    PaperRequestAILatestResponse,
    PaperCrxAbstractClickResponse,
    PaperKickoffRecentPapersResponse,
    PaperSetGitHubRepositoryResponse,
    PaperTranslateAIOverviewResponse,
    PaperKickoffAbstractEmbedResponse,
    PaperProcessAbstractEmbedResponse,
    PaperKickoffPaperCategorizationResponse,
    PaperRequestAITranslationLatestResponse,
)

# pyright: reportDeprecated=false

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestPapers:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_add_author(self, client: AlphaxivCat) -> None:
        paper = client.papers.add_author(
            paper_id="x",
            author_email="dev@stainless.com",
        )
        assert_matches_type(PaperAddAuthorResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_add_author_with_all_params(self, client: AlphaxivCat) -> None:
        paper = client.papers.add_author(
            paper_id="x",
            author_email="dev@stainless.com",
            should_email=True,
        )
        assert_matches_type(PaperAddAuthorResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_add_author(self, client: AlphaxivCat) -> None:
        response = client.papers.with_raw_response.add_author(
            paper_id="x",
            author_email="dev@stainless.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = response.parse()
        assert_matches_type(PaperAddAuthorResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_add_author(self, client: AlphaxivCat) -> None:
        with client.papers.with_streaming_response.add_author(
            paper_id="x",
            author_email="dev@stainless.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = response.parse()
            assert_matches_type(PaperAddAuthorResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_add_author(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_id` but received ''"):
            client.papers.with_raw_response.add_author(
                paper_id="",
                author_email="dev@stainless.com",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_admin_vote(self, client: AlphaxivCat) -> None:
        paper = client.papers.admin_vote(
            paper_id="x",
            entry=0,
        )
        assert_matches_type(PaperAdminVoteResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_admin_vote(self, client: AlphaxivCat) -> None:
        response = client.papers.with_raw_response.admin_vote(
            paper_id="x",
            entry=0,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = response.parse()
        assert_matches_type(PaperAdminVoteResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_admin_vote(self, client: AlphaxivCat) -> None:
        with client.papers.with_streaming_response.admin_vote(
            paper_id="x",
            entry=0,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = response.parse()
            assert_matches_type(PaperAdminVoteResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_admin_vote(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_id` but received ''"):
            client.papers.with_raw_response.admin_vote(
                paper_id="",
                entry=0,
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_crx_abstract_click(self, client: AlphaxivCat) -> None:
        paper = client.papers.crx_abstract_click(
            ref="ref",
            pid="pid",
        )
        assert_matches_type(PaperCrxAbstractClickResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_crx_abstract_click(self, client: AlphaxivCat) -> None:
        response = client.papers.with_raw_response.crx_abstract_click(
            ref="ref",
            pid="pid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = response.parse()
        assert_matches_type(PaperCrxAbstractClickResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_crx_abstract_click(self, client: AlphaxivCat) -> None:
        with client.papers.with_streaming_response.crx_abstract_click(
            ref="ref",
            pid="pid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = response.parse()
            assert_matches_type(PaperCrxAbstractClickResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_crx_abstract_click(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `pid` but received ''"):
            client.papers.with_raw_response.crx_abstract_click(
                ref="ref",
                pid="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `ref` but received ''"):
            client.papers.with_raw_response.crx_abstract_click(
                ref="",
                pid="pid",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_crx_abstract_hit(self, client: AlphaxivCat) -> None:
        paper = client.papers.crx_abstract_hit(
            "pid",
        )
        assert_matches_type(PaperCrxAbstractHitResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_crx_abstract_hit(self, client: AlphaxivCat) -> None:
        response = client.papers.with_raw_response.crx_abstract_hit(
            "pid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = response.parse()
        assert_matches_type(PaperCrxAbstractHitResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_crx_abstract_hit(self, client: AlphaxivCat) -> None:
        with client.papers.with_streaming_response.crx_abstract_hit(
            "pid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = response.parse()
            assert_matches_type(PaperCrxAbstractHitResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_crx_abstract_hit(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `pid` but received ''"):
            client.papers.with_raw_response.crx_abstract_hit(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_crx_pdf_click(self, client: AlphaxivCat) -> None:
        paper = client.papers.crx_pdf_click(
            ref="ref",
            pid="pid",
        )
        assert_matches_type(PaperCrxPdfClickResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_crx_pdf_click(self, client: AlphaxivCat) -> None:
        response = client.papers.with_raw_response.crx_pdf_click(
            ref="ref",
            pid="pid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = response.parse()
        assert_matches_type(PaperCrxPdfClickResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_crx_pdf_click(self, client: AlphaxivCat) -> None:
        with client.papers.with_streaming_response.crx_pdf_click(
            ref="ref",
            pid="pid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = response.parse()
            assert_matches_type(PaperCrxPdfClickResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_crx_pdf_click(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `pid` but received ''"):
            client.papers.with_raw_response.crx_pdf_click(
                ref="ref",
                pid="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `ref` but received ''"):
            client.papers.with_raw_response.crx_pdf_click(
                ref="",
                pid="pid",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_crx_pdf_hit(self, client: AlphaxivCat) -> None:
        paper = client.papers.crx_pdf_hit(
            "pid",
        )
        assert_matches_type(PaperCrxPdfHitResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_crx_pdf_hit(self, client: AlphaxivCat) -> None:
        response = client.papers.with_raw_response.crx_pdf_hit(
            "pid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = response.parse()
        assert_matches_type(PaperCrxPdfHitResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_crx_pdf_hit(self, client: AlphaxivCat) -> None:
        with client.papers.with_streaming_response.crx_pdf_hit(
            "pid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = response.parse()
            assert_matches_type(PaperCrxPdfHitResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_crx_pdf_hit(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `pid` but received ''"):
            client.papers.with_raw_response.crx_pdf_hit(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_email_author(self, client: AlphaxivCat) -> None:
        paper = client.papers.email_author(
            paper_id="x",
            author_individual_email="dev@stainless.com",
            email_author_name="emailAuthorName",
            paper_name="paperName",
            type="comment",
        )
        assert_matches_type(PaperEmailAuthorResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_email_author_with_all_params(self, client: AlphaxivCat) -> None:
        paper = client.papers.email_author(
            paper_id="x",
            author_individual_email="dev@stainless.com",
            email_author_name="emailAuthorName",
            paper_name="paperName",
            type="comment",
            ignore_duplicate_error=True,
        )
        assert_matches_type(PaperEmailAuthorResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_email_author(self, client: AlphaxivCat) -> None:
        response = client.papers.with_raw_response.email_author(
            paper_id="x",
            author_individual_email="dev@stainless.com",
            email_author_name="emailAuthorName",
            paper_name="paperName",
            type="comment",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = response.parse()
        assert_matches_type(PaperEmailAuthorResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_email_author(self, client: AlphaxivCat) -> None:
        with client.papers.with_streaming_response.email_author(
            paper_id="x",
            author_individual_email="dev@stainless.com",
            email_author_name="emailAuthorName",
            paper_name="paperName",
            type="comment",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = response.parse()
            assert_matches_type(PaperEmailAuthorResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_email_author(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_id` but received ''"):
            client.papers.with_raw_response.email_author(
                paper_id="",
                author_individual_email="dev@stainless.com",
                email_author_name="emailAuthorName",
                paper_name="paperName",
                type="comment",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_get_crx_paper_info(self, client: AlphaxivCat) -> None:
        paper = client.papers.get_crx_paper_info(
            "pid",
        )
        assert_matches_type(PaperGetCrxPaperInfoResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_get_crx_paper_info(self, client: AlphaxivCat) -> None:
        response = client.papers.with_raw_response.get_crx_paper_info(
            "pid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = response.parse()
        assert_matches_type(PaperGetCrxPaperInfoResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_get_crx_paper_info(self, client: AlphaxivCat) -> None:
        with client.papers.with_streaming_response.get_crx_paper_info(
            "pid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = response.parse()
            assert_matches_type(PaperGetCrxPaperInfoResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_get_crx_paper_info(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `pid` but received ''"):
            client.papers.with_raw_response.get_crx_paper_info(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_get_paper_info(self, client: AlphaxivCat) -> None:
        paper = client.papers.get_paper_info(
            "pid",
        )
        assert_matches_type(PaperGetPaperInfoResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_get_paper_info(self, client: AlphaxivCat) -> None:
        response = client.papers.with_raw_response.get_paper_info(
            "pid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = response.parse()
        assert_matches_type(PaperGetPaperInfoResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_get_paper_info(self, client: AlphaxivCat) -> None:
        with client.papers.with_streaming_response.get_paper_info(
            "pid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = response.parse()
            assert_matches_type(PaperGetPaperInfoResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_get_paper_info(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `pid` but received ''"):
            client.papers.with_raw_response.get_paper_info(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_kickoff_abstract_embed(self, client: AlphaxivCat) -> None:
        paper = client.papers.kickoff_abstract_embed()
        assert_matches_type(PaperKickoffAbstractEmbedResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_kickoff_abstract_embed(self, client: AlphaxivCat) -> None:
        response = client.papers.with_raw_response.kickoff_abstract_embed()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = response.parse()
        assert_matches_type(PaperKickoffAbstractEmbedResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_kickoff_abstract_embed(self, client: AlphaxivCat) -> None:
        with client.papers.with_streaming_response.kickoff_abstract_embed() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = response.parse()
            assert_matches_type(PaperKickoffAbstractEmbedResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_kickoff_ai(self, client: AlphaxivCat) -> None:
        paper = client.papers.kickoff_ai()
        assert_matches_type(PaperKickoffAIResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_kickoff_ai(self, client: AlphaxivCat) -> None:
        response = client.papers.with_raw_response.kickoff_ai()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = response.parse()
        assert_matches_type(PaperKickoffAIResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_kickoff_ai(self, client: AlphaxivCat) -> None:
        with client.papers.with_streaming_response.kickoff_ai() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = response.parse()
            assert_matches_type(PaperKickoffAIResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_kickoff_bibtex(self, client: AlphaxivCat) -> None:
        paper = client.papers.kickoff_bibtex()
        assert_matches_type(PaperKickoffBibtexResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_kickoff_bibtex(self, client: AlphaxivCat) -> None:
        response = client.papers.with_raw_response.kickoff_bibtex()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = response.parse()
        assert_matches_type(PaperKickoffBibtexResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_kickoff_bibtex(self, client: AlphaxivCat) -> None:
        with client.papers.with_streaming_response.kickoff_bibtex() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = response.parse()
            assert_matches_type(PaperKickoffBibtexResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_kickoff_github(self, client: AlphaxivCat) -> None:
        paper = client.papers.kickoff_github()
        assert_matches_type(PaperKickoffGitHubResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_kickoff_github(self, client: AlphaxivCat) -> None:
        response = client.papers.with_raw_response.kickoff_github()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = response.parse()
        assert_matches_type(PaperKickoffGitHubResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_kickoff_github(self, client: AlphaxivCat) -> None:
        with client.papers.with_streaming_response.kickoff_github() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = response.parse()
            assert_matches_type(PaperKickoffGitHubResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_kickoff_paper_categorization(self, client: AlphaxivCat) -> None:
        paper = client.papers.kickoff_paper_categorization(
            "all",
        )
        assert_matches_type(PaperKickoffPaperCategorizationResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_kickoff_paper_categorization(self, client: AlphaxivCat) -> None:
        response = client.papers.with_raw_response.kickoff_paper_categorization(
            "all",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = response.parse()
        assert_matches_type(PaperKickoffPaperCategorizationResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_kickoff_paper_categorization(self, client: AlphaxivCat) -> None:
        with client.papers.with_streaming_response.kickoff_paper_categorization(
            "all",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = response.parse()
            assert_matches_type(PaperKickoffPaperCategorizationResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_kickoff_paper_categorization(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `all` but received ''"):
            client.papers.with_raw_response.kickoff_paper_categorization(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_kickoff_recent_papers(self, client: AlphaxivCat) -> None:
        paper = client.papers.kickoff_recent_papers()
        assert_matches_type(PaperKickoffRecentPapersResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_kickoff_recent_papers(self, client: AlphaxivCat) -> None:
        response = client.papers.with_raw_response.kickoff_recent_papers()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = response.parse()
        assert_matches_type(PaperKickoffRecentPapersResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_kickoff_recent_papers(self, client: AlphaxivCat) -> None:
        with client.papers.with_streaming_response.kickoff_recent_papers() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = response.parse()
            assert_matches_type(PaperKickoffRecentPapersResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_mark_viewed(self, client: AlphaxivCat) -> None:
        paper = client.papers.mark_viewed(
            "x",
        )
        assert_matches_type(object, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_mark_viewed(self, client: AlphaxivCat) -> None:
        response = client.papers.with_raw_response.mark_viewed(
            "x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = response.parse()
        assert_matches_type(object, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_mark_viewed(self, client: AlphaxivCat) -> None:
        with client.papers.with_streaming_response.mark_viewed(
            "x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = response.parse()
            assert_matches_type(object, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_mark_viewed(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `upid` but received ''"):
            client.papers.with_raw_response.mark_viewed(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_process_abstract_embed(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            paper = client.papers.process_abstract_embed(
                paper_version_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert_matches_type(PaperProcessAbstractEmbedResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_process_abstract_embed(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = client.papers.with_raw_response.process_abstract_embed(
                paper_version_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = response.parse()
        assert_matches_type(PaperProcessAbstractEmbedResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_process_abstract_embed(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            with client.papers.with_streaming_response.process_abstract_embed(
                paper_version_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                paper = response.parse()
                assert_matches_type(PaperProcessAbstractEmbedResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_process_metadata(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            paper = client.papers.process_metadata(
                metadata={},
                universal_paper_id="universalPaperId",
            )

        assert_matches_type(PaperProcessMetadataResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_process_metadata_with_all_params(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            paper = client.papers.process_metadata(
                metadata={
                    "bibtex": True,
                    "custom_categories": True,
                    "embedding": True,
                    "github": True,
                    "organizations": True,
                    "overview": True,
                    "thumbnail": True,
                },
                universal_paper_id="universalPaperId",
            )

        assert_matches_type(PaperProcessMetadataResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_process_metadata(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = client.papers.with_raw_response.process_metadata(
                metadata={},
                universal_paper_id="universalPaperId",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = response.parse()
        assert_matches_type(PaperProcessMetadataResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_process_metadata(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            with client.papers.with_streaming_response.process_metadata(
                metadata={},
                universal_paper_id="universalPaperId",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                paper = response.parse()
                assert_matches_type(PaperProcessMetadataResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_request_ai_latest(self, client: AlphaxivCat) -> None:
        paper = client.papers.request_ai_latest(
            upid="x",
        )
        assert_matches_type(PaperRequestAILatestResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_request_ai_latest_with_all_params(self, client: AlphaxivCat) -> None:
        paper = client.papers.request_ai_latest(
            upid="x",
            preferred_language="am",
        )
        assert_matches_type(PaperRequestAILatestResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_request_ai_latest(self, client: AlphaxivCat) -> None:
        response = client.papers.with_raw_response.request_ai_latest(
            upid="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = response.parse()
        assert_matches_type(PaperRequestAILatestResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_request_ai_latest(self, client: AlphaxivCat) -> None:
        with client.papers.with_streaming_response.request_ai_latest(
            upid="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = response.parse()
            assert_matches_type(PaperRequestAILatestResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_request_ai_latest(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `upid` but received ''"):
            client.papers.with_raw_response.request_ai_latest(
                upid="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_request_ai_translation_latest(self, client: AlphaxivCat) -> None:
        paper = client.papers.request_ai_translation_latest(
            language="am",
            upid="x",
        )
        assert_matches_type(PaperRequestAITranslationLatestResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_request_ai_translation_latest(self, client: AlphaxivCat) -> None:
        response = client.papers.with_raw_response.request_ai_translation_latest(
            language="am",
            upid="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = response.parse()
        assert_matches_type(PaperRequestAITranslationLatestResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_request_ai_translation_latest(self, client: AlphaxivCat) -> None:
        with client.papers.with_streaming_response.request_ai_translation_latest(
            language="am",
            upid="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = response.parse()
            assert_matches_type(PaperRequestAITranslationLatestResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_request_ai_translation_latest(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `upid` but received ''"):
            client.papers.with_raw_response.request_ai_translation_latest(
                language="am",
                upid="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_set_github_repository(self, client: AlphaxivCat) -> None:
        paper = client.papers.set_github_repository(
            paper_id="x",
            github="https://example.com",
        )
        assert_matches_type(PaperSetGitHubRepositoryResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_set_github_repository(self, client: AlphaxivCat) -> None:
        response = client.papers.with_raw_response.set_github_repository(
            paper_id="x",
            github="https://example.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = response.parse()
        assert_matches_type(PaperSetGitHubRepositoryResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_set_github_repository(self, client: AlphaxivCat) -> None:
        with client.papers.with_streaming_response.set_github_repository(
            paper_id="x",
            github="https://example.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = response.parse()
            assert_matches_type(PaperSetGitHubRepositoryResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_set_github_repository(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_id` but received ''"):
            client.papers.with_raw_response.set_github_repository(
                paper_id="",
                github="https://example.com",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_toggle_follow(self, client: AlphaxivCat) -> None:
        paper = client.papers.toggle_follow(
            "x",
        )
        assert_matches_type(PaperToggleFollowResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_toggle_follow(self, client: AlphaxivCat) -> None:
        response = client.papers.with_raw_response.toggle_follow(
            "x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = response.parse()
        assert_matches_type(PaperToggleFollowResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_toggle_follow(self, client: AlphaxivCat) -> None:
        with client.papers.with_streaming_response.toggle_follow(
            "x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = response.parse()
            assert_matches_type(PaperToggleFollowResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_toggle_follow(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_id` but received ''"):
            client.papers.with_raw_response.toggle_follow(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_translate_ai_overview(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            paper = client.papers.translate_ai_overview(
                language="am",
                paper_version_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert_matches_type(PaperTranslateAIOverviewResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_translate_ai_overview(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = client.papers.with_raw_response.translate_ai_overview(
                language="am",
                paper_version_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = response.parse()
        assert_matches_type(PaperTranslateAIOverviewResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_translate_ai_overview(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            with client.papers.with_streaming_response.translate_ai_overview(
                language="am",
                paper_version_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                paper = response.parse()
                assert_matches_type(PaperTranslateAIOverviewResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_translate_ai_overview(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_version_id` but received ''"):
                client.papers.with_raw_response.translate_ai_overview(
                    language="am",
                    paper_version_id="",
                )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_unclaim(self, client: AlphaxivCat) -> None:
        paper = client.papers.unclaim(
            "x",
        )
        assert_matches_type(PaperUnclaimResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_unclaim(self, client: AlphaxivCat) -> None:
        response = client.papers.with_raw_response.unclaim(
            "x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = response.parse()
        assert_matches_type(PaperUnclaimResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_unclaim(self, client: AlphaxivCat) -> None:
        with client.papers.with_streaming_response.unclaim(
            "x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = response.parse()
            assert_matches_type(PaperUnclaimResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_unclaim(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_id` but received ''"):
            client.papers.with_raw_response.unclaim(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_vote(self, client: AlphaxivCat) -> None:
        paper = client.papers.vote(
            "x",
        )
        assert_matches_type(PaperVoteResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_vote(self, client: AlphaxivCat) -> None:
        response = client.papers.with_raw_response.vote(
            "x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = response.parse()
        assert_matches_type(PaperVoteResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_vote(self, client: AlphaxivCat) -> None:
        with client.papers.with_streaming_response.vote(
            "x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = response.parse()
            assert_matches_type(PaperVoteResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_vote(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_id` but received ''"):
            client.papers.with_raw_response.vote(
                "",
            )


class TestAsyncPapers:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_add_author(self, async_client: AsyncAlphaxivCat) -> None:
        paper = await async_client.papers.add_author(
            paper_id="x",
            author_email="dev@stainless.com",
        )
        assert_matches_type(PaperAddAuthorResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_add_author_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        paper = await async_client.papers.add_author(
            paper_id="x",
            author_email="dev@stainless.com",
            should_email=True,
        )
        assert_matches_type(PaperAddAuthorResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_add_author(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.with_raw_response.add_author(
            paper_id="x",
            author_email="dev@stainless.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = await response.parse()
        assert_matches_type(PaperAddAuthorResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_add_author(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.with_streaming_response.add_author(
            paper_id="x",
            author_email="dev@stainless.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = await response.parse()
            assert_matches_type(PaperAddAuthorResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_add_author(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_id` but received ''"):
            await async_client.papers.with_raw_response.add_author(
                paper_id="",
                author_email="dev@stainless.com",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_admin_vote(self, async_client: AsyncAlphaxivCat) -> None:
        paper = await async_client.papers.admin_vote(
            paper_id="x",
            entry=0,
        )
        assert_matches_type(PaperAdminVoteResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_admin_vote(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.with_raw_response.admin_vote(
            paper_id="x",
            entry=0,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = await response.parse()
        assert_matches_type(PaperAdminVoteResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_admin_vote(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.with_streaming_response.admin_vote(
            paper_id="x",
            entry=0,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = await response.parse()
            assert_matches_type(PaperAdminVoteResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_admin_vote(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_id` but received ''"):
            await async_client.papers.with_raw_response.admin_vote(
                paper_id="",
                entry=0,
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_crx_abstract_click(self, async_client: AsyncAlphaxivCat) -> None:
        paper = await async_client.papers.crx_abstract_click(
            ref="ref",
            pid="pid",
        )
        assert_matches_type(PaperCrxAbstractClickResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_crx_abstract_click(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.with_raw_response.crx_abstract_click(
            ref="ref",
            pid="pid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = await response.parse()
        assert_matches_type(PaperCrxAbstractClickResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_crx_abstract_click(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.with_streaming_response.crx_abstract_click(
            ref="ref",
            pid="pid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = await response.parse()
            assert_matches_type(PaperCrxAbstractClickResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_crx_abstract_click(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `pid` but received ''"):
            await async_client.papers.with_raw_response.crx_abstract_click(
                ref="ref",
                pid="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `ref` but received ''"):
            await async_client.papers.with_raw_response.crx_abstract_click(
                ref="",
                pid="pid",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_crx_abstract_hit(self, async_client: AsyncAlphaxivCat) -> None:
        paper = await async_client.papers.crx_abstract_hit(
            "pid",
        )
        assert_matches_type(PaperCrxAbstractHitResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_crx_abstract_hit(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.with_raw_response.crx_abstract_hit(
            "pid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = await response.parse()
        assert_matches_type(PaperCrxAbstractHitResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_crx_abstract_hit(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.with_streaming_response.crx_abstract_hit(
            "pid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = await response.parse()
            assert_matches_type(PaperCrxAbstractHitResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_crx_abstract_hit(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `pid` but received ''"):
            await async_client.papers.with_raw_response.crx_abstract_hit(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_crx_pdf_click(self, async_client: AsyncAlphaxivCat) -> None:
        paper = await async_client.papers.crx_pdf_click(
            ref="ref",
            pid="pid",
        )
        assert_matches_type(PaperCrxPdfClickResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_crx_pdf_click(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.with_raw_response.crx_pdf_click(
            ref="ref",
            pid="pid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = await response.parse()
        assert_matches_type(PaperCrxPdfClickResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_crx_pdf_click(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.with_streaming_response.crx_pdf_click(
            ref="ref",
            pid="pid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = await response.parse()
            assert_matches_type(PaperCrxPdfClickResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_crx_pdf_click(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `pid` but received ''"):
            await async_client.papers.with_raw_response.crx_pdf_click(
                ref="ref",
                pid="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `ref` but received ''"):
            await async_client.papers.with_raw_response.crx_pdf_click(
                ref="",
                pid="pid",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_crx_pdf_hit(self, async_client: AsyncAlphaxivCat) -> None:
        paper = await async_client.papers.crx_pdf_hit(
            "pid",
        )
        assert_matches_type(PaperCrxPdfHitResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_crx_pdf_hit(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.with_raw_response.crx_pdf_hit(
            "pid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = await response.parse()
        assert_matches_type(PaperCrxPdfHitResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_crx_pdf_hit(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.with_streaming_response.crx_pdf_hit(
            "pid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = await response.parse()
            assert_matches_type(PaperCrxPdfHitResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_crx_pdf_hit(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `pid` but received ''"):
            await async_client.papers.with_raw_response.crx_pdf_hit(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_email_author(self, async_client: AsyncAlphaxivCat) -> None:
        paper = await async_client.papers.email_author(
            paper_id="x",
            author_individual_email="dev@stainless.com",
            email_author_name="emailAuthorName",
            paper_name="paperName",
            type="comment",
        )
        assert_matches_type(PaperEmailAuthorResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_email_author_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        paper = await async_client.papers.email_author(
            paper_id="x",
            author_individual_email="dev@stainless.com",
            email_author_name="emailAuthorName",
            paper_name="paperName",
            type="comment",
            ignore_duplicate_error=True,
        )
        assert_matches_type(PaperEmailAuthorResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_email_author(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.with_raw_response.email_author(
            paper_id="x",
            author_individual_email="dev@stainless.com",
            email_author_name="emailAuthorName",
            paper_name="paperName",
            type="comment",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = await response.parse()
        assert_matches_type(PaperEmailAuthorResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_email_author(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.with_streaming_response.email_author(
            paper_id="x",
            author_individual_email="dev@stainless.com",
            email_author_name="emailAuthorName",
            paper_name="paperName",
            type="comment",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = await response.parse()
            assert_matches_type(PaperEmailAuthorResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_email_author(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_id` but received ''"):
            await async_client.papers.with_raw_response.email_author(
                paper_id="",
                author_individual_email="dev@stainless.com",
                email_author_name="emailAuthorName",
                paper_name="paperName",
                type="comment",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_get_crx_paper_info(self, async_client: AsyncAlphaxivCat) -> None:
        paper = await async_client.papers.get_crx_paper_info(
            "pid",
        )
        assert_matches_type(PaperGetCrxPaperInfoResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_get_crx_paper_info(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.with_raw_response.get_crx_paper_info(
            "pid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = await response.parse()
        assert_matches_type(PaperGetCrxPaperInfoResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_get_crx_paper_info(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.with_streaming_response.get_crx_paper_info(
            "pid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = await response.parse()
            assert_matches_type(PaperGetCrxPaperInfoResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_get_crx_paper_info(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `pid` but received ''"):
            await async_client.papers.with_raw_response.get_crx_paper_info(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_get_paper_info(self, async_client: AsyncAlphaxivCat) -> None:
        paper = await async_client.papers.get_paper_info(
            "pid",
        )
        assert_matches_type(PaperGetPaperInfoResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_get_paper_info(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.with_raw_response.get_paper_info(
            "pid",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = await response.parse()
        assert_matches_type(PaperGetPaperInfoResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_get_paper_info(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.with_streaming_response.get_paper_info(
            "pid",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = await response.parse()
            assert_matches_type(PaperGetPaperInfoResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_get_paper_info(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `pid` but received ''"):
            await async_client.papers.with_raw_response.get_paper_info(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_kickoff_abstract_embed(self, async_client: AsyncAlphaxivCat) -> None:
        paper = await async_client.papers.kickoff_abstract_embed()
        assert_matches_type(PaperKickoffAbstractEmbedResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_kickoff_abstract_embed(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.with_raw_response.kickoff_abstract_embed()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = await response.parse()
        assert_matches_type(PaperKickoffAbstractEmbedResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_kickoff_abstract_embed(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.with_streaming_response.kickoff_abstract_embed() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = await response.parse()
            assert_matches_type(PaperKickoffAbstractEmbedResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_kickoff_ai(self, async_client: AsyncAlphaxivCat) -> None:
        paper = await async_client.papers.kickoff_ai()
        assert_matches_type(PaperKickoffAIResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_kickoff_ai(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.with_raw_response.kickoff_ai()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = await response.parse()
        assert_matches_type(PaperKickoffAIResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_kickoff_ai(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.with_streaming_response.kickoff_ai() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = await response.parse()
            assert_matches_type(PaperKickoffAIResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_kickoff_bibtex(self, async_client: AsyncAlphaxivCat) -> None:
        paper = await async_client.papers.kickoff_bibtex()
        assert_matches_type(PaperKickoffBibtexResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_kickoff_bibtex(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.with_raw_response.kickoff_bibtex()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = await response.parse()
        assert_matches_type(PaperKickoffBibtexResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_kickoff_bibtex(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.with_streaming_response.kickoff_bibtex() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = await response.parse()
            assert_matches_type(PaperKickoffBibtexResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_kickoff_github(self, async_client: AsyncAlphaxivCat) -> None:
        paper = await async_client.papers.kickoff_github()
        assert_matches_type(PaperKickoffGitHubResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_kickoff_github(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.with_raw_response.kickoff_github()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = await response.parse()
        assert_matches_type(PaperKickoffGitHubResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_kickoff_github(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.with_streaming_response.kickoff_github() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = await response.parse()
            assert_matches_type(PaperKickoffGitHubResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_kickoff_paper_categorization(self, async_client: AsyncAlphaxivCat) -> None:
        paper = await async_client.papers.kickoff_paper_categorization(
            "all",
        )
        assert_matches_type(PaperKickoffPaperCategorizationResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_kickoff_paper_categorization(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.with_raw_response.kickoff_paper_categorization(
            "all",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = await response.parse()
        assert_matches_type(PaperKickoffPaperCategorizationResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_kickoff_paper_categorization(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.with_streaming_response.kickoff_paper_categorization(
            "all",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = await response.parse()
            assert_matches_type(PaperKickoffPaperCategorizationResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_kickoff_paper_categorization(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `all` but received ''"):
            await async_client.papers.with_raw_response.kickoff_paper_categorization(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_kickoff_recent_papers(self, async_client: AsyncAlphaxivCat) -> None:
        paper = await async_client.papers.kickoff_recent_papers()
        assert_matches_type(PaperKickoffRecentPapersResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_kickoff_recent_papers(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.with_raw_response.kickoff_recent_papers()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = await response.parse()
        assert_matches_type(PaperKickoffRecentPapersResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_kickoff_recent_papers(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.with_streaming_response.kickoff_recent_papers() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = await response.parse()
            assert_matches_type(PaperKickoffRecentPapersResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_mark_viewed(self, async_client: AsyncAlphaxivCat) -> None:
        paper = await async_client.papers.mark_viewed(
            "x",
        )
        assert_matches_type(object, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_mark_viewed(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.with_raw_response.mark_viewed(
            "x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = await response.parse()
        assert_matches_type(object, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_mark_viewed(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.with_streaming_response.mark_viewed(
            "x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = await response.parse()
            assert_matches_type(object, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_mark_viewed(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `upid` but received ''"):
            await async_client.papers.with_raw_response.mark_viewed(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_process_abstract_embed(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            paper = await async_client.papers.process_abstract_embed(
                paper_version_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert_matches_type(PaperProcessAbstractEmbedResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_process_abstract_embed(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = await async_client.papers.with_raw_response.process_abstract_embed(
                paper_version_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = await response.parse()
        assert_matches_type(PaperProcessAbstractEmbedResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_process_abstract_embed(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            async with async_client.papers.with_streaming_response.process_abstract_embed(
                paper_version_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                paper = await response.parse()
                assert_matches_type(PaperProcessAbstractEmbedResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_process_metadata(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            paper = await async_client.papers.process_metadata(
                metadata={},
                universal_paper_id="universalPaperId",
            )

        assert_matches_type(PaperProcessMetadataResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_process_metadata_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            paper = await async_client.papers.process_metadata(
                metadata={
                    "bibtex": True,
                    "custom_categories": True,
                    "embedding": True,
                    "github": True,
                    "organizations": True,
                    "overview": True,
                    "thumbnail": True,
                },
                universal_paper_id="universalPaperId",
            )

        assert_matches_type(PaperProcessMetadataResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_process_metadata(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = await async_client.papers.with_raw_response.process_metadata(
                metadata={},
                universal_paper_id="universalPaperId",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = await response.parse()
        assert_matches_type(PaperProcessMetadataResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_process_metadata(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            async with async_client.papers.with_streaming_response.process_metadata(
                metadata={},
                universal_paper_id="universalPaperId",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                paper = await response.parse()
                assert_matches_type(PaperProcessMetadataResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_request_ai_latest(self, async_client: AsyncAlphaxivCat) -> None:
        paper = await async_client.papers.request_ai_latest(
            upid="x",
        )
        assert_matches_type(PaperRequestAILatestResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_request_ai_latest_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        paper = await async_client.papers.request_ai_latest(
            upid="x",
            preferred_language="am",
        )
        assert_matches_type(PaperRequestAILatestResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_request_ai_latest(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.with_raw_response.request_ai_latest(
            upid="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = await response.parse()
        assert_matches_type(PaperRequestAILatestResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_request_ai_latest(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.with_streaming_response.request_ai_latest(
            upid="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = await response.parse()
            assert_matches_type(PaperRequestAILatestResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_request_ai_latest(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `upid` but received ''"):
            await async_client.papers.with_raw_response.request_ai_latest(
                upid="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_request_ai_translation_latest(self, async_client: AsyncAlphaxivCat) -> None:
        paper = await async_client.papers.request_ai_translation_latest(
            language="am",
            upid="x",
        )
        assert_matches_type(PaperRequestAITranslationLatestResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_request_ai_translation_latest(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.with_raw_response.request_ai_translation_latest(
            language="am",
            upid="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = await response.parse()
        assert_matches_type(PaperRequestAITranslationLatestResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_request_ai_translation_latest(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.with_streaming_response.request_ai_translation_latest(
            language="am",
            upid="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = await response.parse()
            assert_matches_type(PaperRequestAITranslationLatestResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_request_ai_translation_latest(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `upid` but received ''"):
            await async_client.papers.with_raw_response.request_ai_translation_latest(
                language="am",
                upid="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_set_github_repository(self, async_client: AsyncAlphaxivCat) -> None:
        paper = await async_client.papers.set_github_repository(
            paper_id="x",
            github="https://example.com",
        )
        assert_matches_type(PaperSetGitHubRepositoryResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_set_github_repository(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.with_raw_response.set_github_repository(
            paper_id="x",
            github="https://example.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = await response.parse()
        assert_matches_type(PaperSetGitHubRepositoryResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_set_github_repository(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.with_streaming_response.set_github_repository(
            paper_id="x",
            github="https://example.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = await response.parse()
            assert_matches_type(PaperSetGitHubRepositoryResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_set_github_repository(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_id` but received ''"):
            await async_client.papers.with_raw_response.set_github_repository(
                paper_id="",
                github="https://example.com",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_toggle_follow(self, async_client: AsyncAlphaxivCat) -> None:
        paper = await async_client.papers.toggle_follow(
            "x",
        )
        assert_matches_type(PaperToggleFollowResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_toggle_follow(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.with_raw_response.toggle_follow(
            "x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = await response.parse()
        assert_matches_type(PaperToggleFollowResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_toggle_follow(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.with_streaming_response.toggle_follow(
            "x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = await response.parse()
            assert_matches_type(PaperToggleFollowResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_toggle_follow(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_id` but received ''"):
            await async_client.papers.with_raw_response.toggle_follow(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_translate_ai_overview(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            paper = await async_client.papers.translate_ai_overview(
                language="am",
                paper_version_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert_matches_type(PaperTranslateAIOverviewResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_translate_ai_overview(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = await async_client.papers.with_raw_response.translate_ai_overview(
                language="am",
                paper_version_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = await response.parse()
        assert_matches_type(PaperTranslateAIOverviewResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_translate_ai_overview(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            async with async_client.papers.with_streaming_response.translate_ai_overview(
                language="am",
                paper_version_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                paper = await response.parse()
                assert_matches_type(PaperTranslateAIOverviewResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_translate_ai_overview(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_version_id` but received ''"):
                await async_client.papers.with_raw_response.translate_ai_overview(
                    language="am",
                    paper_version_id="",
                )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_unclaim(self, async_client: AsyncAlphaxivCat) -> None:
        paper = await async_client.papers.unclaim(
            "x",
        )
        assert_matches_type(PaperUnclaimResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_unclaim(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.with_raw_response.unclaim(
            "x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = await response.parse()
        assert_matches_type(PaperUnclaimResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_unclaim(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.with_streaming_response.unclaim(
            "x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = await response.parse()
            assert_matches_type(PaperUnclaimResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_unclaim(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_id` but received ''"):
            await async_client.papers.with_raw_response.unclaim(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_vote(self, async_client: AsyncAlphaxivCat) -> None:
        paper = await async_client.papers.vote(
            "x",
        )
        assert_matches_type(PaperVoteResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_vote(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.with_raw_response.vote(
            "x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        paper = await response.parse()
        assert_matches_type(PaperVoteResponse, paper, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_vote(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.with_streaming_response.vote(
            "x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            paper = await response.parse()
            assert_matches_type(PaperVoteResponse, paper, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_vote(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_id` but received ''"):
            await async_client.papers.with_raw_response.vote(
                "",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from ..._models import BaseModel

__all__ = ["V1GetDailyNewAccountsResponse", "V1GetDailyNewAccountsResponseItem"]


class V1GetDailyNewAccountsResponseItem(BaseModel):
    count: float

    date: str


V1GetDailyNewAccountsResponse: TypeAlias = List[V1GetDailyNewAccountsResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["UserGetPrivateNotesParams"]


class UserGetPrivateNotesParams(TypedDict, total=False):
    limit: str
    """Items per page (default: 10)"""

    page: str
    """Page number (default: 0)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v4 import (
    V4Resource,
    AsyncV4Resource,
    V4ResourceWithRawResponse,
    AsyncV4ResourceWithRawResponse,
    V4ResourceWithStreamingResponse,
    AsyncV4ResourceWithStreamingResponse,
)
from .notifications import (
    NotificationsResource,
    AsyncNotificationsResource,
    NotificationsResourceWithRawResponse,
    AsyncNotificationsResourceWithRawResponse,
    NotificationsResourceWithStreamingResponse,
    AsyncNotificationsResourceWithStreamingResponse,
)

__all__ = [
    "V4Resource",
    "AsyncV4Resource",
    "V4ResourceWithRawResponse",
    "AsyncV4ResourceWithRawResponse",
    "V4ResourceWithStreamingResponse",
    "AsyncV4ResourceWithStreamingResponse",
    "NotificationsResource",
    "AsyncNotificationsResource",
    "NotificationsResourceWithRawResponse",
    "AsyncNotificationsResourceWithRawResponse",
    "NotificationsResourceWithStreamingResponse",
    "AsyncNotificationsResourceWithStreamingResponse",
]
